<?php 



// Clean ACF image fields: remove unnecessary metadata like 'sizes'

function clean_acf_images_recursive($data) {

    if (is_array($data)) {

        foreach ($data as $key => &$value) {

            // Check if it's an image array (has 'url' and 'mime_type')

            if (is_array($value) && isset($value['url']) && isset($value['mime_type'])) {

                // Keep only useful fields

                $allowed_keys = ['url', 'alt', 'title', 'width', 'height'];

                $value = array_intersect_key($value, array_flip($allowed_keys));

            } else {

                $value = clean_acf_images_recursive($value); // Recurse into deeper arrays

            }

        }

    }

    return $data;

}



// Modify REST API response for pages and cache ACF data

add_filter('rest_prepare_page', 'optimize_acf_image_fields_in_rest', 20, 3);



function optimize_acf_image_fields_in_rest($response, $post, $request) {

    if (function_exists('get_fields')) {

       

        $acf_fields = get_fields($post->ID);

        $cleaned_fields = clean_acf_images_recursive($acf_fields);

        $response->data['acf'] = $cleaned_fields;

    }



    return $response;

}



add_filter('rest_post_dispatch', function ($response, $server, $request) {

    $route = $request->get_route();



    // Only target ACF Options Page API

    if (strpos($route, '/wp/v2/acf-options/group_') !== false) {

        // Handle both WP_REST_Response and raw array responses

        $data = $response instanceof WP_REST_Response ? $response->get_data() : $response;



        // Ensure $data is an array before processing

        if (isset($data) && is_array($data)) {

            $cleaned_data = clean_acf_images_recursive($data);

            

            // Wrap in WP_REST_Response for consistency

            $response = new WP_REST_Response($cleaned_data, 200);

        }

    }



    return $response;

}, 20, 3);



// Disable unnecessary plugins/hooks during REST requests

if ( defined('REST_REQUEST') && REST_REQUEST ) {

      // Contact Form 7 – Don't load frontend scripts/styles

    remove_action('wp_enqueue_scripts', 'wpcf7_enqueue_scripts');

    remove_action('wp_enqueue_scripts', 'wpcf7_enqueue_styles');

    remove_action('wp_footer', 'wpcf7_recaptcha');





    // CFDB7 – Only needed for backend admin

    remove_action('init', 'cfdb7_init');





    //Yoast SEO – Heavy for REST calls

    remove_action('plugins_loaded', 'wpseo_init');





    // WP Mail SMTP – No mailing needed during API calls

    remove_action('plugins_loaded', 'wp_mail_smtp');





    // Smash Balloon Instagram Feed – Skip REST-side rendering

    remove_action('init', 'sb_instagram_init');





    // Safe SVG – Only relevant for uploads in admin, not API

    remove_action('init', 'safe_svg_init');



}

